(* $Id: nn_alloc_balanced.mli 525 2011-11-29 08:01:34Z gerd $ *)

(** Block allocation algorithm *)

val get_allocsize : int -> int
  (** Get the allocation size for the blocksize. The allocation size is the
      number of blocks that are allocated at once
   *)

val allocate_balanced_strategy : 
      inode:int64 ->
      Nn_blockmap.blockmap_t list ->
      Nn_alloc_types.transacted_datastores ->
      Nn_blockmap.owner ->
      int ->
      int64 ->
      int ->
      int ->
      string list ->
      Nn_blockmap.reserve_info ->
         Nn_blocklist.blocklist
  (** [allocate_balanced_strategy inode bmaps td owner repl index number bs pref]:
      Allocates blocks for the index range [index] to [index+number-1].
      The replication factor is [repl]. The blocks are allocated in the
      passed blockmaps [bmaps], and will be assigned to [owner].
      Tickets are generated for the transaction identified by [td].
      In [bs] the blocksize must be passed. The list [pref] can contain
      the identities of preferred datanodes; if possible blocks are
      allocated there.

      This algorithm allocates blocks in ranges, and tries to get a
      balanced allocation with respect to the datanodes.

      May raise {!Nn_alloc_types.No_space}.
   *)

(*
val repair_blocklist :
      inode:int64 ->
      Nn_blockmap.blockmap_t list ->
      Nn_alloc_types.transacted_datastores ->
      Nn_blockmap.owner ->
      int ->
      int64 ->
      int ->
      int ->
      string list ->
      string list ->
      Nn_blocklist.blocklist ->
         Nn_blocklist.blocklist
  (** [repair_blocklist inode bmaps td owner repl index number bs pref decom
       in_blist]
      Repair the existing block list [in_blist]:
       - find replacement blocks for dead nodes
       - find replacement blocks for identities in [decom], decommissioned nodes
       - find additonal blocks if the repliaction factor is increased

      The input block list [in_blist] must not have holes (these would be
      treated as zero-replicated regions, causing a failure).

      [repl] is the target replication factor. The output blocklist guarantees
      this factor (if impossible to reach this, the function will fail).

      New blocks are preferably allocated on the identities in [pref].

      Failures:
       - {!Nn_alloc_types.No_space]
       - {!Nn_alloc_types.Dead_block]

   *)

 *)
